//////////////////////////////////////////////////
//////////////Grass Animation Shader//////////////
//////////////////////////////////////////////////
////11.06.2008////////////////by Nils Daumann/////
/////////////slindev.wordpress.com////////////////
//////////////////////////////////////////////////

var GA_WindStrength = 5;

MATERIAL* GrassAnimate_mat =
{
	effect =
	"
		//Variables
		float4x4 matProj, matView, matWorld;
		float4 vecTime, vecLight, vecFog, vecViewPos, vecSkill41;
		
		
		//samplers
		sampler ColorMap;
		

		//Vertexshader
		void mainVS(	in float4 inPos : POSITION,
							in float2 inTex0 : TEXCOORD0,
							out float4 Pos	: POSITION,
							out float  Fog	: FOG,
							out float2 Tex0 : TEXCOORD0)
		{
			inPos = mul(inPos,matWorld);
			
			//set the new vertex position
			inPos += vecSkill41.x*(inPos.y-vecSkill41.z) *	//the movement strength depends on the height of the vertex
						float4(sin(vecTime.w*vecSkill41.y+inPos.x),0,cos(vecTime.w*vecSkill41.y+inPos.y),0);	//the animation
			
			//do the final vertex transformation
			Pos = mul(float4(inPos.xyz,1.0),mul(matView,matProj));
			
			//fog
			Fog = 1 - (distance(inPos,vecViewPos)-vecFog.x) * vecFog.z;
			
			//pass the texcoords
			Tex0 = inTex0;
		}
		
		
		//Pixelshader
		float4 mainPS(in float2 Tex0 : TEXCOORD0) : COLOR
		{
			//get the color and apply ambient lighting
			float4 Color = tex2D(ColorMap,Tex0)*float4(vecLight.rgb+0.5,1.0);
			return float4(Color.rgb,step(0.5,Color.a));
		}
		
		
		//technique
		technique water_env
		{
			pass one
			{
				//make sure that it is sorted right
				AlphaTestEnable = true;
				ZWriteEnable = true;
				CullMode = none;
				
				//compile the shaders
				VertexShader = compile vs_1_1 mainVS();
				PixelShader = compile ps_1_4 mainPS();
			}
		}
	";
}


action Grass_act()
{
	set(my,PASSABLE);
	my.material = GrassAnimate_mat;
	bmap_to_mipmap(ent_getskin(my,1));
	
	while(1)
	{
		vec_set(my.skill41,vector(floatd(GA_WindStrength,80),floatd(GA_WindStrength,30),my.z));	//range, speed, height of the models origin
		
		wait(1);
	}
}